======================
Abaqus Output Database
======================

The Python ODB API commands are used to read and write data from an output database (.odb) file. The path to the Odb object can be via the session.odbs repository or via a variable. In this chapter the Access and Path statements refer to a variable called odb that represents an existing Odb object.

Object features
---------------

Odb
~~~

.. autoclass:: abaqus.Odb.Odb.Odb
    :members:
    :inherited-members:

    .. autoclasstoc::

OdbBase
~~~~~~~

.. autoclass:: abaqus.Odb.OdbBase.OdbBase
    :members:

    .. autoclasstoc::

AmplitudeOdb
~~~~~~~~~~~~

.. autoclass:: abaqus.Amplitude.AmplitudeOdb.AmplitudeOdb
    :members:

    .. autoclasstoc::

FilterOdb
~~~~~~~~~

.. autoclass:: abaqus.FilterFilterOdb.FilterOdb
    :members:

    .. autoclasstoc::

MaterialOdb
~~~~~~~~~~~

.. autoclass:: abaqus.Material.MaterialOdb.MaterialOdb
    :members:

    .. autoclasstoc::

BeamSectionProfileOdb
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileOdb.BeamSectionProfileOdb
    :members:

    .. autoclasstoc::

AnalyticSurface
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.AnalyticSurface.AnalyticSurface
    :members:

    .. autoclasstoc::

AnalyticSurfaceSegment
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.AnalyticSurfaceSegment.AnalyticSurfaceSegment
    :members:

    .. autoclasstoc::

BeamOrientation
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.BeamOrientation.BeamOrientation
    :members:

    .. autoclasstoc::

BeamOrientationArray
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.BeamOrientationArray.BeamOrientationArray
    :members:

    .. autoclasstoc::

FieldBulkData
~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.FieldBulkData.FieldBulkData
    :members:

    .. autoclasstoc::

FieldLocation
~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.FieldLocation.FieldLocation
    :members:

    .. autoclasstoc::

FieldLocationArray
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.FieldLocationArray.FieldLocationArray
    :members:

    .. autoclasstoc::

FieldOutput
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.FieldOutput.FieldOutput
    :members:

    .. autoclasstoc::

FieldValue
~~~~~~~~~~

.. autoclass:: abaqus.Odb.FieldValue.FieldValue
    :members:

    .. autoclasstoc::

FieldValueArray
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.FieldValueArray.FieldValueArray
    :members:

    .. autoclasstoc::

HistoryOutput
~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.HistoryOutput.HistoryOutput
    :members:

    .. autoclasstoc::

HistoryPoint
~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.HistoryPoint.HistoryPoint
    :members:

    .. autoclasstoc::

HistoryRegion
~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.HistoryRegion.HistoryRegion
    :members:

    .. autoclasstoc::

JobData
~~~~~~~

.. autoclass:: abaqus.Odb.JobData.JobData
    :members:

    .. autoclasstoc::

OdbAssembly
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbAssembly.OdbAssembly
    :members:
    :inherited-members:

    .. autoclasstoc::

OdbAssemblyBase
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbAssemblyBase.OdbAssemblyBase
    :members:

    .. autoclasstoc::

OdbCommands
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbCommands.OdbCommands
    :members:

    .. autoclasstoc::

OdbDatumCsys
~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbDatumCsys.OdbDatumCsys
    :members:

    .. autoclasstoc::

OdbFrame
~~~~~~~~

.. autoclass:: abaqus.Odb.OdbFrame.OdbFrame
    :members:

    .. autoclasstoc::

OdbFrameArray
~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbFrameArray.OdbFrameArray
    :members:

    .. autoclasstoc::

OdbInstance
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbInstance.OdbInstance
    :members:
    :inherited-members:

    .. autoclasstoc::

OdbInstanceBase
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbInstanceBase.OdbInstanceBase
    :members:

    .. autoclasstoc::

OdbLoadCase
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbLoadCase.OdbLoadCase
    :members:

    .. autoclasstoc::

OdbMeshElement
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbMeshElement.OdbMeshElement
    :members:

    .. autoclasstoc::

OdbMeshElementArray
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbMeshElementArray.OdbMeshElementArray
    :members:

    .. autoclasstoc::

OdbMeshNode
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbMeshNode.OdbMeshNode
    :members:

    .. autoclasstoc::

OdbMeshNodeArray
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbMeshNodeArray.OdbMeshNodeArray
    :members:

    .. autoclasstoc::

OdbPart
~~~~~~~

.. autoclass:: abaqus.Odb.OdbPart.OdbPart
    :members:
    :inherited-members:

    .. autoclasstoc::

OdbPartBase
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbPartBase.OdbPartBase
    :members:

    .. autoclasstoc::

OdbPretensionSection
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbPretensionSection.OdbPretensionSection
    :members:

    .. autoclasstoc::

OdbPretensionSectionArray
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbPretensionSectionArray.OdbPretensionSectionArray
    :members:

    .. autoclasstoc::

OdbRigidBody
~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbRigidBody.OdbRigidBody
    :members:

    .. autoclasstoc::

OdbRigidBodyArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbRigidBodyArray.OdbRigidBodyArray
    :members:

    .. autoclasstoc::

OdbSequenceAnalyticSurfaceSegment
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbSequenceAnalyticSurfaceSegment.OdbSequenceAnalyticSurfaceSegment
    :members:

    .. autoclasstoc::

OdbSession
~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbSession.OdbSession
    :members:

    .. autoclasstoc::

OdbSet
~~~~~~

.. autoclass:: abaqus.Odb.OdbSet.OdbSet
    :members:

    .. autoclasstoc::

OdbStep
~~~~~~~

.. autoclass:: abaqus.Odb.OdbStep.OdbStep
    :members:
    :inherited-members:

    .. autoclasstoc::

OdbStepBase
~~~~~~~~~~~

.. autoclass:: abaqus.Odb.OdbStepBase.OdbStepBase
    :members:

    .. autoclasstoc::

RebarOrientation
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.RebarOrientation.RebarOrientation
    :members:

    .. autoclasstoc::

RebarOrientationArray
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.RebarOrientationArray.RebarOrientationArray
    :members:

    .. autoclasstoc::

ScratchOdb
~~~~~~~~~~

.. autoclass:: abaqus.Odb.ScratchOdb.ScratchOdb
    :members:

    .. autoclasstoc::

SectionCategory
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.SectionCategory.SectionCategory
    :members:

    .. autoclasstoc::

SectionPoint
~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.SectionPoint.SectionPoint
    :members:

    .. autoclasstoc::

SectionPointArray
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.SectionPointArray.SectionPointArray
    :members:

    .. autoclasstoc::

SectorDefinition
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.SectorDefinition.SectorDefinition
    :members:

    .. autoclasstoc::

UserData
~~~~~~~~

.. autoclass:: abaqus.Odb.UserData.UserData
    :members:
    :inherited-members:

    .. autoclasstoc::

UserDataBase
~~~~~~~~~~~~

.. autoclass:: abaqus.Odb.UserDataBase.UserDataBase
    :members:

    .. autoclasstoc::

